%define ssldir %(/usr/bin/openssl version -d | cut -f2 -d\\")

Summary: CERN CA certificate for use with openssl
Name: openssl-CERN-CA-certs
Version: 20100216
Release: 1%{?dist}
URL: http://cern.ch/ca
Packager: Linux.Support@cern.ch
Source0: %{name}-%{version}.tar.gz
License: distributable
Group: System/Security
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: openssl
Requires: %{ssldir}
Obsoletes: openssl-CERN-CA-certificates openssl-CERN-CA-certificates-slc5
BuildArch: noarch


%description
openssl versions of the CERN Certificate authority (https://cern.ch/ca).

Install this if you would like openssl (and other commands that use
openssl libraries) to trust certificates signed by this CA.


%prep
%setup -q

%build

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{ssldir}/{certs,crl}

cd $RPM_BUILD_ROOT/%{ssldir}/certs

for i in CERN_Root_CA.crt CERN_Trusted_Certification_Authority.crt; do

  j=`basename $i .crt`
  openssl x509 -inform DER -in "${RPM_BUILD_DIR}/%{name}-%{version}/${i}" -outform PEM -out "${j}.pem"

  num=`cat "${j}.pem" | grep -E 'BEGIN.* CERTIFICATE' | wc -l`
  if [ "$num" -gt 1 ]; then
     echo "Error: more than 1 certificate in $j.pem, can't handle"
     exit 7
  fi

  hash=`openssl x509 -in  $j.pem -noout -hash`
  # is this always .0? or should we have the version here?
  # not until we get a clash, this is a uniqifier.
  ln -s "${j}.pem" "${hash}.0"


  # subject:
  subject=`openssl x509 -subject -noout -in $j.pem | sed -e 's/subject= *//'`


  # signing policy
  cat > "${j}.signing_policy" <<EOF
access_id_CA      X509         '$subject'
pos_rights        globus        CA:sign
cond_subjects     globus     '"/DC=ch/DC=cern/*"'
EOF

  ln -s "${j}.signing_policy" "${hash}.signing_policy"

  chmod 0444 *
done

# CRL?


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{ssldir}/certs/*

%changelog
* Tue Feb 16 2010 Jan van Eldik <Jan.van.Eldik@cern.ch>
- Unify builds on SLC4 and SLC5

* Fri May  4 2007 Jan Iven  <jan.iven@cern.ch> -20061003.1
- Initial build.


